@@ -17,4 +17,17 @@ class ManyToManyField(models.ManyToManyField):
             "model_field": self.model_field,
         }
         defaults.update(kwargs)
+        return super(self.__class__, self).formfield(**defaults)
+
+class ForeignKey(models.ForeignKey):
+    def __init__(self, to, **kwargs):
+        self.to = to
+        super(self.__class__, self).__init__(to, **kwargs)
+
+    def formfield(self, **kwargs):
+        defaults = {
+            'form_class': form_fields.ModelChoiceField,
+            "to": self.to,
+        }
+        defaults.update(kwargs)
         return super(self.__class__, self).formfield(**defaults)
\ No newline at end of file
